@@ -1,7 +1,7 @@
-#from unittest import TestCase
 import re
 from contextlib import contextmanager
 
+from pydocx.DocxParser import OPCPart, OPCRelationship
 from pydocx.parsers.Docx2Html import Docx2Html
 from pydocx.utils import (
     parse_xml_from_string,
@@ -11,18 +11,19 @@ from unittest import TestCase
 
 STYLE = (
     '<style>'
-    '.pydocx-insert {color:green;}'
-    '.pydocx-delete {color:red;text-decoration:line-through;}'
-    '.pydocx-center {text-align:center;}'
-    '.pydocx-right {text-align:right;}'
-    '.pydocx-left {text-align:left;}'
-    '.pydocx-comment {color:blue;}'
-    '.pydocx-underline {text-decoration: underline;}'
-    '.pydocx-caps {text-transform:uppercase;}'
-    '.pydocx-small-caps {font-variant: small-caps;}'
-    '.pydocx-strike {text-decoration: line-through;}'
-    '.pydocx-hidden {visibility: hidden;}'
-    'body {width:612px;margin:0px auto;}'
+    '.pydocx-caps {text-transform:uppercase}'
+    '.pydocx-center {text-align:center}'
+    '.pydocx-comment {color:blue}'
+    '.pydocx-delete {color:red;text-decoration:line-through}'
+    '.pydocx-hidden {visibility:hidden}'
+    '.pydocx-insert {color:green}'
+    '.pydocx-left {text-align:left}'
+    '.pydocx-right {text-align:right}'
+    '.pydocx-small-caps {font-variant:small-caps}'
+    '.pydocx-strike {text-decoration:line-through}'
+    '.pydocx-tab {display:inline-block;width:4em}'
+    '.pydocx-underline {text-decoration:underline}'
+    'body {margin:0px auto;width:51.00em}'
     '</style>'
 )
 
@@ -88,41 +89,29 @@ class XMLDocx2Html(Docx2Html):
     """
     def __init__(self, *args, **kwargs):
         # Pass in nothing for the path
+        self.document_xml = kwargs.pop('document_xml')
+        self.relationships = kwargs.pop('relationships')
+        self.numbering_dict = kwargs.pop('numbering_dict', None) or {}
+        self.styles_dict = kwargs.pop('styles_dict', None) or {}
         super(XMLDocx2Html, self).__init__(path=None, *args, **kwargs)
 
-    def _build_data(
-            self,
-            path,
-            document_xml=None,
-            rels_dict=None,
-            numbering_dict=None,
-            styles_dict=None,
-            *args, **kwargs):
-        self._test_rels_dict = rels_dict
-        if rels_dict:
-            for value in rels_dict.values():
-                self._image_data['word/%s' % value] = 'word/%s' % value
-        self.numbering_root = None
-        if numbering_dict is not None:
-            self.numbering_root = parse_xml_from_string(
-                DXB.numbering(numbering_dict),
-            )
-        self.numbering_dict = numbering_dict
-        # Intentionally not calling super
-        if document_xml is not None:
-            self.root = parse_xml_from_string(document_xml)
-        self.zip_path = ''
+    def _load(self):
+        self.document = OPCPart(raw_data=self.document_xml)
+        if self.relationships:
+            for relationship in self.relationships:
+                self.document.add_relationship(OPCRelationship(**relationship))
 
-        # This is the standard page width for a word document, Also the page
-        # width that we are looking for in the test.
+        self.numbering_root = None
+        if self.numbering_dict is not None:
+            self.numbering_root = parse_xml_from_string(
+                DXB.numbering(self.numbering_dict),
+            )
+
+        # This is the standard page width for a word document (in points), Also
+        # the page width that we are looking for in the test.
         self.page_width = 612
 
-        self.styles_dict = styles_dict
-
-    def _parse_rels_root(self, *args, **kwargs):
-        if self._test_rels_dict is None:
-            return {}
-        return self._test_rels_dict
+        self.parse_begin(self.document.xml_tree)
 
     def get_list_style(self, num_id, ilvl):
         try:
@@ -130,11 +119,6 @@ class XMLDocx2Html(Docx2Html):
         except KeyError:
             return 'decimal'
 
-    def _parse_styles(self):
-        if self.styles_dict is None:
-            return {}
-        return self.styles_dict
-
 
 DEFAULT_NUMBERING_DICT = {
     '1': {
@@ -150,7 +134,7 @@ DEFAULT_NUMBERING_DICT = {
 
 class _TranslationTestCase(TestCase):
     expected_output = None
-    relationship_dict = None
+    relationships = None
     styles_dict = None
     numbering_dict = DEFAULT_NUMBERING_DICT
     run_expected_output = True
@@ -179,13 +163,10 @@ class _TranslationTestCase(TestCase):
         # Verify the final output.
         parser = self.parser
 
-        def image_handler(self, src, *args, **kwargs):
-            return src
-        parser.image_handler = image_handler
         html = parser(
             convert_root_level_upper_roman=self.convert_root_level_upper_roman,
             document_xml=tree,
-            rels_dict=self.relationship_dict,
+            relationships=self.relationships,
             numbering_dict=self.numbering_dict,
             styles_dict=self.styles_dict,
         ).parsed
